@@ -4,6 +4,8 @@ available_on_bioc <- function(name, repos = NULL, ...) {
   if (is.null(repos)) {
     if (requireNamespace("BiocInstaller", quietly = TRUE)) {
       repos <- BiocInstaller::biocinstallRepos()
+    } else if (requireNamespace("BiocManager", quietly = TRUE)) {
+      repos <- BiocManager::repositories()
     } else {
       # Search on latest bioc release
       repos <- c(
