@@ -5,6 +5,8 @@
 #' @export
 available_on_github <- function(name) {
   github_names <- gh_pkg(name)
+  my_links <- github_link_location()
+  github_names <- github_names[!github_names[["pkg_location"]] %in% my_links, ]
 
   same <- tolower(name) == tolower(github_names[["pkg_name"]])
   if (any(same)) {
@@ -29,7 +31,7 @@ available_on_github <- function(name) {
 gh_pkg <- memoise::memoise(function(pkg) {
   res <- jsonlite::fromJSON(paste0("http://rpkg-api.gepuro.net/rpkg?q=", pkg))
   if (length(res) == 0) {
-    return(list(pkg_name = "", pkg_org = ""))
+    return(data.frame(pkg_name = character(), pkg_location = character(), pkg_org = character()))
   }
   res$pkg_location <- res$pkg_name
   res$pkg_org <- vapply(strsplit(res$pkg_location, "/"), `[[`, character(1), 1)
@@ -49,3 +51,14 @@ print.available_github <- function(x, ...) {
   cat(format(x, ...))
   invisible(x)
 }
+
+github_link_location <- function() {
+  tryCatch({
+    desc <- desc::desc()
+    urls <- desc$get_urls()
+    gh_links <- grep("^https?://github.com/", urls, value = TRUE)
+
+    gsub("https?://github.com/(.*)/?$", "\\1", gh_links)
+  },
+  error = function(e) character(0))
+}
